@@ -53,7 +53,7 @@ from OpenGL.GL.ARB.framebuffer_object import (
 
 from xpra.os_util import (
     monotonic_time, strtobytes, hexstr,
-    POSIX, PYTHON2, OSX,
+    POSIX, PYTHON2, PYTHON3, OSX,
     DummyContextManager,
     )
 from xpra.util import envint, envbool, repr_ellipsized
@@ -76,7 +76,7 @@ PAINT_FLUSH = envbool("XPRA_PAINT_FLUSH", True)
 JPEG_YUV = envbool("XPRA_JPEG_YUV", True)
 WEBP_YUV = envbool("XPRA_WEBP_YUV", True)
 FORCE_CLONE = envbool("XPRA_OPENGL_FORCE_CLONE", False)
-DRAW_REFRESH = envbool("XPRA_OPENGL_DRAW_REFRESH", False)
+DRAW_REFRESH = envbool("XPRA_OPENGL_DRAW_REFRESH", PYTHON3)
 FBO_RESIZE = envbool("XPRA_OPENGL_FBO_RESIZE", True)
 FBO_RESIZE_DELAY = envint("XPRA_OPENGL_FBO_RESIZE_DELAY", 50)
 CONTEXT_REINIT = envbool("XPRA_OPENGL_CONTEXT_REINIT", OSX)
@@ -529,7 +529,13 @@ class GLWindowBackingBase(WindowBackingBase):
         glTexImage2D(target, 0, self.internal_format, w, h, 0, self.texture_pixel_format, GL_UNSIGNED_BYTE, None)
         glBindFramebuffer(GL_FRAMEBUFFER, fbo)
         glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, target, self.textures[texture_index], 0)
-        glClear(GL_COLOR_BUFFER_BIT)
+        self.gl_clear_color_buffer()
+
+    def gl_clear_color_buffer(self):
+        try:
+            glClear(GL_COLOR_BUFFER_BIT)
+        except Exception:
+            log("ignoring glClear(GL_COLOR_BUFFER_BIT) error, buggy driver?", exc_info=True)
 
 
     def close_gl_config(self):
@@ -703,7 +709,7 @@ class GLWindowBackingBase(WindowBackingBase):
             # black, no alpha:
             glClearColor(0.0, 0.0, 0.0, 1.0)
         if left or top or right or bottom:
-            glClear(GL_COLOR_BUFFER_BIT)
+            self.gl_clear_color_buffer()
 
         #from now on, take the offsets into account:
         glViewport(left, top, ww, wh)
@@ -1061,10 +1067,10 @@ class GLWindowBackingBase(WindowBackingBase):
                 glBindTexture(target, 0)
                 glDisable(target)
                 self.paint_box(options.strget("encoding"), options.intget("delta", -1)>=0, x, y, width, height)
-                fire_paint_callbacks(callbacks)
                 # Present update to screen
                 self.present_fbo(x, y, width, height, options.intget("flush", 0))
                 # present_fbo has reset state already
+            fire_paint_callbacks(callbacks)
             return
         except GLError as e:
             message = "OpenGL %s paint failed: %r" % (rgb_format, e)
