@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2017-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2017-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -10,24 +10,30 @@ import socket
 import subprocess
 from collections import OrderedDict
 
-from xpra.gtk_common.gobject_compat import import_gtk, import_gdk, import_pango, import_glib
-gtk = import_gtk()
-gdk = import_gdk()
-pango = import_pango()
-glib = import_glib()
-glib.threads_init()
-
 from xpra.platform.paths import get_icon_dir, get_xpra_command, get_nodock_command
 from xpra.platform.dotxpra import DotXpra
 from xpra.child_reaper import getChildReaper
 from xpra.exit_codes import EXIT_STR
-from xpra.gtk_common.gtk_util import gtk_main, add_close_accel, pixbuf_new_from_file, TableBuilder, scaled_image, color_parse, imagebutton, STATE_NORMAL, WIN_POS_CENTER
+from xpra.gtk_common.gtk_util import (
+    gtk_main, add_close_accel, pixbuf_new_from_file, TableBuilder, scaled_image, color_parse,
+    imagebutton, STATE_NORMAL, WIN_POS_CENTER,
+    )
+from xpra.gtk_common.gobject_compat import (
+    import_gtk, import_gdk, import_pango, import_glib,
+    register_os_signals,
+    )
 from xpra.net.net_util import if_indextoname
-from xpra.util import typedict
+from xpra.util import typedict, DEFAULT_PORTS
 from xpra.os_util import bytestostr, WIN32
 from xpra.log import Logger
+
 log = Logger("client", "util")
 
+gtk = import_gtk()
+gdk = import_gdk()
+pango = import_pango()
+glib = import_glib()
+
 
 class SessionsGUI(gtk.Window):
 
@@ -86,7 +92,7 @@ class SessionsGUI(gtk.Window):
         try:
             from xpra.platform.info import get_username
             username = get_username()
-        except:
+        except Exception:
             username = ""
         #log.info("options=%s (%s)", options, type(options))
         self.local_info_cache = {}
@@ -103,13 +109,17 @@ class SessionsGUI(gtk.Window):
 
     def do_quit(self):
         log("do_quit()")
+        self.cleanup()
         gtk.main_quit()
 
-    def app_signal(self, signum, frame):
+    def app_signal(self, signum):
         self.exit_code = 128 + signum
-        log("app_signal(%s, %s) exit_code=%i", signum, frame, self.exit_code)
+        log("app_signal(%s) exit_code=%i", signum, self.exit_code)
         self.do_quit()
 
+    def cleanup(self):
+        self.destroy()
+
 
     def update(self):
         if self.poll_local_sessions():
@@ -163,7 +173,7 @@ class SessionsGUI(gtk.Window):
                     text[name] = v
             return text
         #first remove any records that are no longer found:
-        for key in self.local_info_cache.keys():
+        for key in self.local_info_cache:
             if key not in info_cache:
                 display, sockpath = key
                 self.records = [(interface, protocol, name, stype, domain, host, address, port, text) for
@@ -187,7 +197,7 @@ class SessionsGUI(gtk.Window):
             socktype = "socket"
         cmd = get_nodock_command()+["id", "%s:%s" % (socktype, sockpath)]
         p = subprocess.Popen(cmd, stdin=None, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout, _ = p.communicate()
+        stdout = p.communicate()[0]
         log("get_sessions_info(%s) returncode(%s)=%s", sockpath, cmd, p.returncode)
         if p.returncode!=0:
             return None
@@ -214,12 +224,16 @@ class SessionsGUI(gtk.Window):
             return
         self.set_size_request(-1, -1)
         tb = TableBuilder(1, 6, False)
-        tb.add_row(gtk.Label("Host"), gtk.Label("Display"), gtk.Label("Name"), gtk.Label("Platform"), gtk.Label("Type"), gtk.Label("URI"), gtk.Label("Connect"), gtk.Label("Open in Browser"))
+        labels = [gtk.Label(x) for x in (
+            "Host", "Display", "Name", "Platform", "Type", "URI", "Connect", "Open in Browser",
+            )]
+        tb.add_row(*labels)
         self.table = tb.get_table()
         self.vbox.add(self.table)
         self.table.resize(1+len(self.records), 5)
         #group them by uuid
         d = OrderedDict()
+        session_names = {}
         for i, record in enumerate(self.records):
             interface, protocol, name, stype, domain, host, address, port, text = record
             td = typedict(text)
@@ -228,19 +242,22 @@ class SessionsGUI(gtk.Window):
             display = td.strget("display", "")
             platform = td.strget("platform", "")
             dtype = td.strget("type", "")
-            #older servers expose the "session-name" as "session":
-            session_name = td.strget("name", "") or td.strget("session", "")
             if domain=="local" and host.endswith(".local"):
                 host = host[:-len(".local")]
-            key = (uuid, uuid or i, host, display, session_name, platform, dtype)
+            key = (uuid, uuid or i, host, display, platform, dtype)
             log("populate_table: key[%i]=%s", i, key)
             d.setdefault(key, []).append((interface, protocol, name, stype, domain, host, address, port, text))
+            #older servers expose the "session-name" as "session":
+            td = typedict(text)
+            session_name = td.strget("name", "") or td.strget("session", "")
+            if session_name:
+                session_names[key] = session_name
         for key, recs in d.items():
-            if type(key)==tuple:
-                uuid, _, host, display, name, platform, dtype = key
+            if isinstance(key, tuple):
+                uuid, _, host, display, platform, dtype = key
             else:
                 display = key
-                uuid, host, name, platform, dtype = None, None, "", sys.platform, None
+                uuid, host, platform, dtype = None, None, sys.platform, None
             title = uuid
             if display:
                 title = display
@@ -257,7 +274,8 @@ class SessionsGUI(gtk.Window):
             if not pwidget:
                 pwidget = gtk.Label(platform)
             w, c, b = self.make_connect_widgets(key, recs, address, port, display)
-            tb.add_row(gtk.Label(host), label, gtk.Label(name), pwidget, gtk.Label(dtype), w, c, b)
+            session_name = session_names.get(key, "")
+            tb.add_row(gtk.Label(host), label, gtk.Label(session_name), pwidget, gtk.Label(dtype), w, c, b)
         self.table.show_all()
 
     def get_uri(self, password, interface, protocol, name, stype, domain, host, address, port, text):
@@ -266,6 +284,17 @@ class SessionsGUI(gtk.Window):
         display = tt.strget("display", "")
         username = tt.strget("username", "")
         mode = tt.strget("mode", "")
+        if not mode:
+            #guess the mode from the service name,
+            #ie: "localhost.localdomain :2 (wss)" -> "wss"
+            #ie: "localhost.localdomain :2 (ssh-2)" -> "ssh"
+            pos = name.rfind("(")
+            if name.endswith(")") and pos>0:
+                mode = name[pos+1:-1].split("-")[0]
+                if mode not in ("tcp", "ws", "wss", "ssl", "ssh"):
+                    return ""
+            else:
+                mode = "tcp"
         if display and display.startswith(":"):
             dstr = display[1:]
         #append interface to IPv6 host URI for link local addresses ("fe80:"):
@@ -279,7 +308,7 @@ class SessionsGUI(gtk.Window):
                 uri = "%s://%s@%s" % (mode, username, address)
         else:
             uri = "%s://%s" % (mode, address)
-        if port>0:
+        if port>0 and DEFAULT_PORTS.get(mode, 0)!=port:
             uri += ":%s" % port
         if protocol not in ("socket", "namedpipe"):
             uri += "/"
@@ -303,7 +332,7 @@ class SessionsGUI(gtk.Window):
                 self.warning.set_text(EXIT_STR.get(c, "exit code %s" % c).replace("_", " "))
             try:
                 del self.clients[key]
-            except:
+            except KeyError:
                 pass
             else:
                 def update():
@@ -330,7 +359,6 @@ class SessionsGUI(gtk.Window):
 
     def make_connect_widgets(self, key, recs, address, port, display):
         d = {}
-
         proc = self.clients.get(key)
         if proc and proc.poll() is None:
             icon = self.get_pixbuf("disconnected.png")
@@ -428,9 +456,7 @@ def do_main(opts):
     with program_context("Xpra-Session-Browser", "Xpra Session Browser"):
         enable_color()
         gui = SessionsGUI(opts)
-        import signal
-        signal.signal(signal.SIGINT, gui.app_signal)
-        signal.signal(signal.SIGTERM, gui.app_signal)
+        register_os_signals(gui.app_signal)
         gtk_main()
         log("do_main() gui.exit_code=%i", gui.exit_code)
         return gui.exit_code
