@@ -101,7 +101,7 @@ class Keyboard(KeyboardBase):
                 layout = locale.get("X11 Layout")
                 if layout:
                     query_struct["layout"] = layout
-            log("query_struct(locale)=%s", locale, query_struct)
+            log("query_struct(%s)=%s", locale, query_struct)
             return None, None, query_struct
         query_struct = self.keyboard_bindings.getXkbProperties()
         _query = xkbmap_query_tostring(query_struct)
