@@ -223,9 +223,11 @@ def get_build_info():
             BUILD_DATE, BUILD_TIME, BUILD_BIT,
             CYTHON_VERSION, COMPILER_VERSION,
             )
+        info.insert(0, "")
+        einfo = "Python %i.%i" % sys.version_info[:2]
         if BUILD_BIT:
-            info.insert(0, "")
-            info.insert(0, BUILD_BIT)
+            einfo += ", "+BUILD_BIT
+        info.insert(0, einfo)
         try:
             from xpra.build_info import BUILT_BY, BUILT_ON
             info.append("built on %s by %s" % (BUILT_ON, BUILT_BY))
@@ -1005,7 +1007,7 @@ def get_defaults():
                     "av-sync"           : True,
                     "exit-ssh"          : True,
                     "dbus-control"      : not WIN32 and not OSX,
-                    "opengl"            : "probe",
+                    "opengl"            : "no" if (WIN32 and not PYTHON2) else "probe",
                     "mdns"              : not WIN32,
                     "swap-keys"         : OSX,  #only used on osx
                     "desktop-fullscreen": False,
