@@ -282,6 +282,7 @@ class X11ServerBase(X11ServerCore):
             dpi, double_click_time, double_click_distance)
         log("overrides: antialias=%s", antialias)
         self._settings.update(settings)
+        from xpra.x11.xsettings_prop import XSettingsTypeInteger, XSettingsTypeString, BLACKLISTED_XSETTINGS
         for k, v in settings.items():
             #cook the "resource-manager" value to add the DPI and/or antialias values:
             if k==b"resource-manager" and (dpi>0 or antialias or cursor_size>0):
@@ -296,6 +297,9 @@ class X11ServerBase(X11ServerCore):
                     if len(parts)!=2:
                         log("skipped invalid option: '%s'", option)
                         continue
+                    if parts[0] in BLACKLISTED_XSETTINGS:
+                        log("skipped blacklisted option: '%s'", option)
+                        continue
                     values[parts[0]] = parts[1]
                 if cursor_size>0:
                     values["Xcursor.size"] = cursor_size
@@ -333,7 +337,17 @@ class X11ServerBase(X11ServerCore):
             #(as those may not be present in xsettings on some platforms.. like win32 and osx)
             if k==b"xsettings-blob" and \
             (self.double_click_time>0 or self.double_click_distance!=(-1, -1) or antialias or dpi>0):
-                from xpra.x11.xsettings_prop import XSettingsTypeInteger, XSettingsTypeString
+                #start by removing blacklisted options:
+                def filter_blacklisted():
+                    serial, values = v
+                    new_values = []
+                    for _t,_n,_v,_s in values:
+                        if bytestostr(_n) in BLACKLISTED_XSETTINGS:
+                            log("skipped blacklisted option %s", (_t, _n, _v, _s))
+                        else:
+                            new_values.append((_t, _n, _v, _s))
+                    return serial, new_values
+                v = filter_blacklisted()
                 def set_xsettings_value(name, value_type, value):
                     #remove existing one, if any:
                     serial, values = v
